assert1

Dependencies:   mbed X_NUCLEO_IHM02A1

Revision:
3:06cbe2f6c494
Parent:
2:977799d72329
--- a/hardware.cpp	Sat Feb 23 16:30:08 2019 +0000
+++ b/hardware.cpp	Sat Mar 30 15:10:23 2019 +0000
@@ -8,16 +8,16 @@
 // PWM_MAX est définit dans réglage;
 bool moteurs_arret = false;
 
-DigitalIn tirette(D9);
+DigitalIn tirette(PB_8);
 
 
 XNucleoIHM02A1 *x_nucleo_ihm02a1; //Création d'une entité pour la carte de contôle des pas à pas
 L6470_init_t init[L6470DAISYCHAINSIZE] = {
     /* First Motor. */
      {
-        12.0,                           /* Motor supply voltage in V. */
+        4.08,                           /* Motor supply voltage in V. */ //4.08
         400,                           /* Min number of steps per revolution for the motor. */
-        7.5,                           /* Max motor phase voltage in A. */
+        3,                           /* Max motor phase voltage in A. */ 
         7.06,                          /* Max motor phase voltage in V. */
         300.0,                         /* Motor initial speed [step/s]. */
         500.0,                         /* Motor acceleration [step/s^2] (comment for infinite acceleration mode). */
@@ -43,9 +43,9 @@
 
     /* Second Motor. */
     {
-        12.0,                           /* Motor supply voltage in V. */
+        4.08,                           /* Motor supply voltage in V. */
         400,                           /* Min number of steps per revolution for the motor. */
-        7.5,                           /* Max motor phase voltage in A. */
+        3,                           /* Max motor phase voltage in A. */ //7.5 
         7.06,                          /* Max motor phase voltage in V. */
         300.0,                         /* Motor initial speed [step/s]. */
         500.0,                         /* Motor acceleration [step/s^2] (comment for infinite acceleration mode). */
@@ -74,7 +74,7 @@
 
 DigitalOut led(LED2);
 Serial pc(USBTX, USBRX); // tx, rx
-DevSPI dev_spi(D11, D12, D13); //pour la F746ZG, connecter D13 et D3 par un fil 
+DevSPI dev_spi(D11, D12, D3); //pour la F746ZG, connecter D13 et D3 par un fil 
 
 
 //Connections codeuses